# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"folder": "14scop.ipynb",
         "plot_scop": "14scop.ipynb",
         "Parameters": "14scop.ipynb",
         "Variable": "14scop.ipynb",
         "Model": "14scop.ipynb",
         "Constraint": "14scop.ipynb",
         "Linear": "14scop.ipynb",
         "Quadratic": "14scop.ipynb",
         "Alldiff": "14scop.ipynb"}

modules = ["scop.py"]

doc_url = "https://mikiokubo.github.io/scoptrial/"

git_url = "https://github.com/mikiokubo/scoptrial/tree/master/"

def custom_doc_links(name): return None
